@@ -15,6 +15,7 @@ from omegaconf import (
     read_write,
 )
 
+from hydra import version
 from hydra.core.config_search_path import ConfigSearchPath
 from hydra.core.object_type import ObjectType
 from hydra.plugins.config_source import ConfigResult, ConfigSource
@@ -177,7 +178,7 @@ class ConfigRepository(IConfigRepository):
     ) -> List[InputDefault]:
         def issue_deprecated_name_warning() -> None:
             # DEPRECATED: remove in 1.2
-            url = "https://hydra.cc/docs/next/upgrades/1.0_to_1.1/changes_to_package_header"
+            url = "https://hydra.cc/docs/1.2/upgrades/1.0_to_1.1/changes_to_package_header"
             deprecation_warning(
                 message=dedent(
                     f"""\
@@ -190,10 +191,11 @@ class ConfigRepository(IConfigRepository):
         for item in defaults._iter_ex(resolve=False):
             default: InputDefault
             if isinstance(item, DictConfig):
-                old_optional = None
-                if len(item) > 1:
-                    if "optional" in item:
-                        old_optional = item.pop("optional")
+                if not version.base_at_least("1.2"):
+                    old_optional = None
+                    if len(item) > 1:
+                        if "optional" in item:
+                            old_optional = item.pop("optional")
                 keys = list(item.keys())
 
                 if len(keys) > 1:
@@ -209,23 +211,24 @@ class ConfigRepository(IConfigRepository):
                 keywords = ConfigRepository.Keywords()
                 self._extract_keywords_from_config_group(config_group, keywords)
 
-                if not keywords.optional and old_optional is not None:
-                    keywords.optional = old_optional
+                if not version.base_at_least("1.2"):
+                    if not keywords.optional and old_optional is not None:
+                        keywords.optional = old_optional
 
                 node = item._get_node(key)
                 assert node is not None and isinstance(node, Node)
                 config_value = node._value()
 
-                if old_optional is not None:
-                    # DEPRECATED: remove in 1.2
-                    msg = dedent(
-                        f"""
-                        In {config_path}: 'optional: true' is deprecated.
-                        Use 'optional {key}: {config_value}' instead.
-                        Support for the old style will be removed in Hydra 1.2"""
-                    )
+                if not version.base_at_least("1.2"):
+                    if old_optional is not None:
+                        msg = dedent(
+                            f"""
+                            In {config_path}: 'optional: true' is deprecated.
+                            Use 'optional {key}: {config_value}' instead.
+                            Support for the old style is removed for Hydra version_base >= 1.2"""
+                        )
 
-                    deprecation_warning(msg)
+                        deprecation_warning(msg)
 
                 if config_value is not None and not isinstance(
                     config_value, (str, list)
@@ -247,8 +250,9 @@ class ConfigRepository(IConfigRepository):
                         options.append(vv)
                     config_value = options
 
-                if package is not None and "_name_" in package:
-                    issue_deprecated_name_warning()
+                if not version.base_at_least("1.2"):
+                    if package is not None and "_name_" in package:
+                        issue_deprecated_name_warning()
 
                 default = GroupDefault(
                     group=keywords.group,
@@ -260,8 +264,9 @@ class ConfigRepository(IConfigRepository):
 
             elif isinstance(item, str):
                 path, package, _package2 = self._split_group(item)
-                if package is not None and "_name_" in package:
-                    issue_deprecated_name_warning()
+                if not version.base_at_least("1.2"):
+                    if package is not None and "_name_" in package:
+                        issue_deprecated_name_warning()
 
                 default = ConfigDefault(path=path, package=package)
             else:
