@@ -9,7 +9,7 @@ from typing import Callable, Dict, List, Optional, Set, Tuple, Union
 
 from omegaconf import DictConfig, OmegaConf
 
-from hydra import MissingConfigException
+from hydra import MissingConfigException, version
 from hydra._internal.config_repository import IConfigRepository
 from hydra.core.config_store import ConfigStore
 from hydra.core.default_element import (
@@ -244,7 +244,7 @@ def _validate_self(
         if containing_node.primary and has_config_content and has_non_override:
             msg = (
                 f"In '{containing_node.get_config_path()}': Defaults list is missing `_self_`. "
-                f"See https://hydra.cc/docs/upgrades/1.0_to_1.1/default_composition_order for more information"
+                f"See https://hydra.cc/docs/1.2/upgrades/1.0_to_1.1/default_composition_order for more information"
             )
             if os.environ.get("SELF_WARNING_AS_ERROR") == "1":
                 raise ConfigCompositionException(msg)
@@ -307,6 +307,7 @@ def _check_not_missing(
             return True
         if isinstance(default, GroupDefault):
             group_path = default.get_group_path()
+            override_key = default.get_override_key()
             options = repo.get_group_options(
                 group_path,
                 results_filter=ObjectType.CONFIG,
@@ -314,7 +315,7 @@ def _check_not_missing(
             opt_list = "\n".join(["\t" + x for x in options])
             msg = dedent(
                 f"""\
-                You must specify '{group_path}', e.g, {group_path}=<OPTION>
+                You must specify '{override_key}', e.g, {override_key}=<OPTION>
                 Available options:
                 """
             )
@@ -380,7 +381,10 @@ def _update_overrides(
         legacy_hydra_override = False
         if isinstance(d, GroupDefault):
             assert d.group is not None
-            legacy_hydra_override = not d.is_override() and d.group.startswith("hydra/")
+            if not version.base_at_least("1.2"):
+                legacy_hydra_override = not d.is_override() and d.group.startswith(
+                    "hydra/"
+                )
 
         if seen_override and not (
             d.is_override() or d.is_external_append() or legacy_hydra_override
@@ -399,9 +403,8 @@ def _update_overrides(
 
         if isinstance(d, GroupDefault):
             if legacy_hydra_override:
-                # DEPRECATED: remove in 1.2
                 d.override = True
-                url = "https://hydra.cc/docs/next/upgrades/1.0_to_1.1/defaults_list_override"
+                url = "https://hydra.cc/docs/1.2/upgrades/1.0_to_1.1/defaults_list_override"
                 msg = dedent(
                     f"""\
                     In {parent.get_config_path()}: Invalid overriding of {d.group}:
@@ -434,7 +437,7 @@ def _has_config_content(cfg: DictConfig) -> bool:
         return False
 
     for key in cfg.keys():
-        if not OmegaConf.is_missing(cfg, key):
+        if not OmegaConf.is_missing(cfg, key) and key != "defaults":
             return True
     return False
 
@@ -543,26 +546,22 @@ def _create_defaults_tree_impl(
 
             if isinstance(d, GroupDefault) and d.is_options():
                 # overriding may change from options to name
-                if d.is_options():
-                    for item in reversed(d.get_options()):
-                        if "${" in item:
-                            raise ConfigCompositionException(
-                                f"In '{path}': Defaults List interpolation is not supported in options list items"
-                            )
+                for item in reversed(d.get_options()):
+                    if "${" in item:
+                        raise ConfigCompositionException(
+                            f"In '{path}': Defaults List interpolation is not supported in options list items"
+                        )
 
-                        assert d.group is not None
-                        node = ConfigDefault(
-                            path=d.group + "/" + item,
-                            package=d.package,
-                            optional=d.is_optional(),
-                        )
-                        node.update_parent(
-                            parent.get_group_path(), parent.get_final_package()
-                        )
-                        new_root = DefaultsTreeNode(node=node, parent=root)
-                        add_child(children, new_root)
-                else:
-                    new_root = DefaultsTreeNode(node=d, parent=root)
+                    assert d.group is not None
+                    node = ConfigDefault(
+                        path=d.group + "/" + item,
+                        package=d.package,
+                        optional=d.is_optional(),
+                    )
+                    node.update_parent(
+                        parent.get_group_path(), parent.get_final_package()
+                    )
+                    new_root = DefaultsTreeNode(node=node, parent=root)
                     add_child(children, new_root)
 
             else:
